import { Root } from './Root';
import { JoiOriginal } from '../libs';
import { CLASS_DATA_ATTRIBUTES } from '../symbols';
import { IAttribute, IAttributes } from '../types';
export interface IDataOptions {
    acceptAllData?: boolean;
}
export declare abstract class Data<I extends object = {}> extends Root {
    [CLASS_DATA_ATTRIBUTES]: IAttributes;
    options: IDataOptions;
    /**
     * ClassData constructor loads a initial state of the object, if needed.
     * @param initialData
     */
    constructor(initialData?: I, options?: IDataOptions);
    protected assign(initialData: object): this;
    set(attributes: object): this;
    /**
     * Loop through each data attribute of the class an run
     * a serialization function on the value, if provided
     */
    serialize(): object;
    /**
     * Loop through each key of a given object, and will try to load
     * the values in the object if their keys is found in the data class
     * attribute list. If provided, will run a de-serialization function
     * on each value.
     *
     * @param object
     */
    deserialize(object: {}): object;
    /**
     * Deep check if an attribute exists. Please refer to lodash for more details.
     *
     * @param key
     */
    has(key: string): boolean;
    /**
     * Creates an object composed of the picked object properties.
     *
     * @param paths
     */
    pick(paths: string[]): object;
    /**
     * Gets the value at `path`. Returns `defaultValue` or false if nothing is found.
     *
     * @param path
     * @param defaultValue
     */
    get<I = any>(path: string, defaultValue?: any): I;
    getAndValidate<I = any>(path: string, validationRule: JoiOriginal.JoiObject): I;
    /**
     * Checks if the value at `path` equals `value`
     *
     * @param path
     * @param value
     */
    is(path: string, value: any): boolean;
    /**
     * The opposite of `pick`; this method creates an object composed of the own and inherited enumerable property paths that are not omitted.
     *
     * @param paths
     */
    omit(paths: string[]): object;
    toJSON(): object;
    toString(): string;
    private attributesDiscoveredInAllDataMode;
    protected getAttributeDefinitions(data?: object): {
        key: string;
        attrDef: IAttribute;
    }[];
    /**
     * Dirty state management
     */
    private initialData;
    protected resetDirtyState(): this;
    protected getDirtyAttributes(): string[];
}
