"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Validation = void 0;
const Data_1 = require("./Data");
const utils_1 = require("../utils");
const libs_1 = require("../libs");
class Validation extends Data_1.Data {
    /**
     * Runs before any validations are run
     */
    preValidate() {
        return;
    }
    /**
     * Runs after successful validation ran
     */
    postValidate() {
        return;
    }
    /**
     * Runs the validation of each data class attributes and
     * throw an exception if one of the attribute is not valid.
     */
    validate() {
        const callPreValidate = () => {
            this.debug('::preValidate', 'airboat:validation');
            return this.preValidate();
        };
        const callPostValidate = () => {
            this.debug('::postValidate', 'airboat:validation');
            return this.postValidate();
        };
        const callValidate = () => {
            this.debug('::validate', 'airboat:validation');
            const validationErrors = [];
            const newValues = {};
            this.getAttributeDefinitions().forEach(({ key, attrDef }) => {
                if (attrDef.validation) {
                    const results = libs_1.Joi.validate(this[key], attrDef.validation);
                    if (results.error) {
                        validationErrors.push(results.error.message.replace('"value"', `${this.getClassNameForErrorMessage()}.${key}`));
                    }
                    else {
                        newValues[key] = results.value;
                    }
                }
                else {
                    newValues[key] = this[key];
                }
            });
            if (validationErrors.length >= 1) {
                throw utils_1.Exception.badRequest(validationErrors.join('; '));
            }
            Object.assign(this, newValues);
        };
        callPreValidate();
        callValidate();
        callPostValidate();
        return this;
    }
    getClassNameForErrorMessage() {
        return this.constructor.name;
    }
}
exports.Validation = Validation;
//# sourceMappingURL=Validation.js.map