"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
const Validation_1 = require("./Validation");
const decorators_1 = require("../decorators");
const libs_1 = require("../libs");
class MySubCLass extends Validation_1.Validation {
}
__decorate([
    decorators_1.Attribute({ validation: libs_1.Joi.string().min(5).required() })
], MySubCLass.prototype, "name", void 0);
class MyClass extends Validation_1.Validation {
}
__decorate([
    decorators_1.Attribute(libs_1.Joi.string().min(5).required())
], MyClass.prototype, "name", void 0);
__decorate([
    decorators_1.Attribute.model(MySubCLass)
], MyClass.prototype, "subModel", void 0);
test('Should validate the payload of the class', () => {
    const instance = new MyClass({ name: 'my-name', subModel: { name: 'hello' } });
    expect(instance.name).toBe('my-name');
    instance.validate();
    expect(instance.name).toBe('my-name');
});
test('Should throw a 400 when the payload is invalid', () => {
    const instance = new MyClass({ name: 'my' });
    expect(instance.name).toBe('my');
    try {
        instance.validate();
        throw 'should-fail';
    }
    catch (e) {
        expect(e.output.statusCode).toBe(400);
    }
});
test('Should throw is a required sub-model is not present', () => {
    class MySubModel extends Validation_1.Validation {
    }
    __decorate([
        decorators_1.Attribute({ validation: libs_1.Joi.string().required() })
    ], MySubModel.prototype, "name", void 0);
    class MyModel extends Validation_1.Validation {
    }
    __decorate([
        decorators_1.Attribute.model(MySubModel)
    ], MyModel.prototype, "sub", void 0);
    const instance = new MyModel();
    try {
        instance.validate();
        throw 'should-fail';
    }
    catch (e) {
        expect(e.message).toBe('MySubModel.name is required');
        expect(e.output.statusCode).toBe(400);
    }
});
test('Should pass validation with an empty optional sub-model', () => {
    class MySubModel extends Validation_1.Validation {
    }
    __decorate([
        decorators_1.Attribute(libs_1.Joi.string().required())
    ], MySubModel.prototype, "name", void 0);
    __decorate([
        decorators_1.Attribute.uuid()
    ], MySubModel.prototype, "id", void 0);
    class MyModel extends Validation_1.Validation {
    }
    __decorate([
        decorators_1.Attribute.model(MySubModel, { optional: true })
    ], MyModel.prototype, "sub", void 0);
    const instance = new MyModel();
    const result = instance.validate();
    expect(result.sub.serialize()).toEqual({});
    expect(result.sub.id).toBe(undefined);
});
//# sourceMappingURL=Validation.spec.js.map