"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpClient = void 0;
const utils_1 = require("../../utils");
const libs_1 = require("../../libs");
const Request = require("request-promise");
class HttpClient {
    constructor(config) {
        this.config = config;
    }
    async get(path, payload = {}) {
        return this.request('GET', path, payload);
    }
    async post(path, payload = {}) {
        return this.request('POST', path, payload);
    }
    async put(path, payload = {}) {
        return this.request('PUT', path, payload);
    }
    async delete(path, payload = {}) {
        return this.request('DELETE', path, payload);
    }
    serializePayload(payload) {
        return JSON.stringify(payload);
    }
    deserializePayload(payload) {
        return JSON.parse(payload);
    }
    deserializeExceptionMessage(response) {
        if (response.error) {
            return response.error;
        }
        return JSON.stringify(response.body);
    }
    triggerException(response) {
        throw utils_1.Exception.badRequest(this.deserializeExceptionMessage(response));
    }
    extendRawRequest(rawRequest) {
        return rawRequest;
    }
    getTimeout() {
        return 1500;
    }
    getHeader() {
        return { 'Content-Type': 'application/json' };
    }
    getUrl(path) {
        return `https://${this.config['domain']}${path}`;
    }
    async request(method, path, payload = {}) {
        // Create the basic request
        const requestTemplate = {
            method,
            url: this.getUrl(path),
            timeout: this.getTimeout(),
            headers: this.getHeader(),
            resolveWithFullResponse: true,
        };
        // Format the payload of the request
        if (method === 'POST' || method === 'PUT') {
            requestTemplate['body'] = this.serializePayload(payload);
        }
        else if (!libs_1._.isEmpty(payload)) {
            requestTemplate['qs'] = payload;
        }
        // Execute the request
        const finalRequest = this.extendRawRequest(requestTemplate);
        try {
            this.rawResponse = await Request(finalRequest);
        }
        catch (e) {
            this.triggerException(e); // throw
        }
        return this.deserializePayload(this.rawResponse.body);
    }
}
exports.HttpClient = HttpClient;
//# sourceMappingURL=client.js.map