"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = void 0;
const Debugger = require("debug");
const utils_1 = require("../../utils");
var Logger;
(function (Logger) {
    const loggers = new Map();
    Logger.addLogger = (key, logger) => {
        utils_1.Assert(!loggers.has(key), utils_1.Exception.internal(`logger ${key} already exists`));
        loggers.set(key, logger);
    };
    Logger.flush = async () => {
        for (const [key, logger] of loggers) {
            await logger.flush();
        }
    };
    Logger.log = (message, namespace = 'default', context = {}) => {
        for (const [key, logger] of loggers) {
            logger.log(message, namespace, context);
        }
    };
    Logger.createSegment = (keys, context = {}) => {
        for (const [key, logger] of loggers) {
            logger.createSegment(keys, context);
        }
    };
    /**
     * @deprecated Please change to Logger.log()
     */
    function error(message, namespace = 'default') {
        Logger.log(message, namespace);
    }
    Logger.error = error;
    /**
     * @deprecated Please change to Logger.log()
     */
    function warn(message, namespace = 'default') {
        Logger.log(message, namespace);
    }
    Logger.warn = warn;
    function debug(message, namespace = 'airboat:default') {
        Debugger(namespace)(message);
    }
    Logger.debug = debug;
})(Logger = exports.Logger || (exports.Logger = {}));
//# sourceMappingURL=index.js.map